@@ -11,21 +11,18 @@ use overload    #
   },
   fallback => undef;
 
-has app => ( is => 'ro', isa => ConsumerOf ['Pcore::App'], required => 1 );
-has is_authenticated => ( is => 'ro', isa => Bool, required => 1 );
+has app              => ();    # ( isa => ConsumerOf ['Pcore::App'], required => 1 );
+has is_authenticated => ();    # ( isa => Bool, required => 1 );
+has private_token    => ();    # ( isa => Maybe [ArrayRef] );    # [ $token_type, $token_id, $token_hash ]
+has is_root          => ();    # ( isa => Bool );
+has user_id          => ();    # ( isa => Maybe [Str] );
+has user_name        => ();    # ( isa => Maybe [Str] );
+has permissions      => ();    # ( isa => Maybe [HashRef] );
+has depends_on       => ();    # ( isa => Maybe [ArrayRef] );
 
-has private_token => ( is => 'ro', isa => Maybe [ArrayRef] );    # [ $token_type, $token_id, $token_hash ]
-
-has is_root   => ( is => 'ro', isa => Bool );
-has user_id   => ( is => 'ro', isa => Maybe [Str] );
-has user_name => ( is => 'ro', isa => Maybe [Str] );
-
-has permissions => ( is => 'ro', isa => Maybe [HashRef] );
-has depends_on  => ( is => 'ro', isa => Maybe [ArrayRef] );
-
-sub TO_DATA ($self) {
+*TO_JSON = *TO_CBOR = sub ($self) {
     die q[Direct auth object serialization is impossible for security reasons];
-}
+};
 
 sub TO_DUMP ( $self, $dumper, @ ) {
     my %args = (
